sqlobject.inheritance.tests.test\_foreignKey module
===================================================

.. automodule:: sqlobject.inheritance.tests.test_foreignKey
    :members:
    :undoc-members:
    :show-inheritance:
